@@ -32,9 +32,7 @@
 #include <datetime/planner-snooze.h>
 #include <datetime/planner-range.h>
 #include <datetime/settings-live.h>
-#ifdef LOMIRI_FEATURES_ENABLED
 #include <datetime/snap.h>
-#endif
 #include <datetime/state.h>
 #include <datetime/timezones-live.h>
 #include <datetime/timezone-timedated.h>
@@ -95,7 +93,6 @@ namespace
         return state;
     }
 
-#ifdef LOMIRI_FEATURES_ENABLED
     std::shared_ptr<AlarmQueue> create_simple_alarm_queue(const std::shared_ptr<Clock>& clock,
                                                           const std::shared_ptr<Planner>& snooze_planner,
                                                           const std::shared_ptr<Engine>& engine,
@@ -119,7 +116,6 @@ namespace
         auto wakeup_timer = std::make_shared<PowerdWakeupTimer>(clock);
         return std::make_shared<SimpleAlarmQueue>(clock, planner, wakeup_timer);
     }
-#endif
 }
 
 int
@@ -149,7 +145,6 @@ main(int /*argc*/, char** /*argv*/)
     auto actions = std::make_shared<LiveActions>(state);
     MenuFactory factory(actions, state);
 
-#ifdef LOMIRI_FEATURES_ENABLED
     // set up the snap decisions
     auto snooze_planner = std::make_shared<SnoozePlanner>(state->settings, state->clock);
     auto notification_engine = std::make_shared<ain::Engine>("ayatana-indicator-datetime-service");
@@ -173,7 +168,6 @@ main(int /*argc*/, char** /*argv*/)
         engine->disable_alarm(appointment);
     };
     alarm_queue->alarm_reached().connect(on_alarm_reached);
-#endif
 
     // create the menus
     std::vector<std::shared_ptr<Menu>> menus;
