@@ -1,6 +1,6 @@
 /*
  * Copyright 2015 Canonical Ltd.
- * Copyright 2021-2024 Robert Tari
+ * Copyright 2021-2025 Robert Tari
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 3, as published
@@ -80,7 +80,11 @@ TEST_F(VAlarmFixture, MultipleAppointments)
 
     // what we expect to get...
     Appointment expected_appt;
+#ifndef LOMIRI_FEATURES_ENABLED
     expected_appt.uid = "20150507T211449Z-4262-32011-1418-1@lomiri-phablet";
+#else
+    expected_appt.uid = "840ab899-1b0e-4697-9514-dcd336a5e125";
+#endif
     expected_appt.summary = "Alarm";
     std::array<Alarm,8> expected_alarms = {
         Alarm({"Alarm", "file://" ALARM_DEFAULT_SOUND, DateTime(gtz,2015,5, 8,16,40,0)}),
@@ -106,7 +110,11 @@ TEST_F(VAlarmFixture, MultipleAppointments)
         EXPECT_PRED3([](auto sColourIn, auto sColourExpected1, auto sColourExpected2)
         {
             return sColourIn == sColourExpected1 || sColourIn == sColourExpected2;
+    #ifndef LOMIRI_FEATURES_ENABLED
         }, appt.color, "#becedd", "#62a0ea");
+    #else
+        }, appt.color, "#0000FF", "");
+    #endif
     }
 
     // cleanup
